@@ -13,16 +13,15 @@
 
 using namespace CalendarSupport;
 
-MessageWidget::MessageWidget(QWidget *parent) : KMessageWidget(parent)
+MessageWidget::MessageWidget(QWidget *parent)
+    : KMessageWidget(parent)
 {
     hide();
     setCloseButtonVisible(false);
     setWordWrap(true);
 }
 
-MessageWidget::~MessageWidget()
-{
-}
+MessageWidget::~MessageWidget() = default;
 
 void MessageWidget::showEvent(QShowEvent *event)
 {
@@ -45,7 +44,7 @@ bool MessageWidget::eventFilter(QObject *, QEvent *event)
     }
 
     if (event->type() == QEvent::KeyPress) {
-        auto *ev = static_cast<QKeyEvent *>(event);
+        auto ev = static_cast<QKeyEvent *>(event);
         hide();
         if (ev->key() == Qt::Key_Escape) {
             return true; // We eat this one, it's for us
@@ -54,3 +53,5 @@ bool MessageWidget::eventFilter(QObject *, QEvent *event)
 
     return false; // we don't want it
 }
+
+#include "moc_messagewidget.cpp"
